Documents
=========
This directory includes documents, slide decks and API documents in HTML format.

## API documents
The API documents are created by [sphinx](http://www.sphinx-doc.org/en/stable/). You can read the doc by accessing api/_build/html/index.html.
Of course, you can create various types of API doc by using make command as follows:
```
make **builder**
```
*\*builder\** could be html, latex and so on. You can find the list of builder by just executing `make`.
